nixio package
=============

Subpackages
-----------

.. toctree::

   nixio.cmd
   nixio.exceptions
   nixio.hdf5
   nixio.test
   nixio.util

Submodules
----------

nixio.block module
------------------

.. automodule:: nixio.block
   :members:
   :undoc-members:
   :show-inheritance:

nixio.compression module
------------------------

.. automodule:: nixio.compression
   :members:
   :undoc-members:
   :show-inheritance:

nixio.container module
----------------------

.. automodule:: nixio.container
   :members:
   :undoc-members:
   :show-inheritance:

nixio.data\_array module
------------------------

.. automodule:: nixio.data_array
   :members:
   :undoc-members:
   :show-inheritance:

nixio.data\_frame module
------------------------

.. automodule:: nixio.data_frame
   :members:
   :undoc-members:
   :show-inheritance:

nixio.data\_set module
----------------------

.. automodule:: nixio.data_set
   :members:
   :undoc-members:
   :show-inheritance:

nixio.data\_view module
-----------------------

.. automodule:: nixio.data_view
   :members:
   :undoc-members:
   :show-inheritance:

nixio.datatype module
---------------------

.. automodule:: nixio.datatype
   :members:
   :undoc-members:
   :show-inheritance:

nixio.dimension\_type module
----------------------------

.. automodule:: nixio.dimension_type
   :members:
   :undoc-members:
   :show-inheritance:

nixio.dimensions module
-----------------------

.. automodule:: nixio.dimensions
   :members:
   :undoc-members:
   :show-inheritance:

nixio.entity module
-------------------

.. automodule:: nixio.entity
   :members:
   :undoc-members:
   :show-inheritance:

nixio.feature module
--------------------

.. automodule:: nixio.feature
   :members:
   :undoc-members:
   :show-inheritance:

nixio.file module
-----------------

.. automodule:: nixio.file
   :members:
   :undoc-members:
   :show-inheritance:

nixio.group module
------------------

.. automodule:: nixio.group
   :members:
   :undoc-members:
   :show-inheritance:

nixio.info module
-----------------

.. automodule:: nixio.info
   :members:
   :undoc-members:
   :show-inheritance:

nixio.link\_type module
-----------------------

.. automodule:: nixio.link_type
   :members:
   :undoc-members:
   :show-inheritance:

nixio.multi\_tag module
-----------------------

.. automodule:: nixio.multi_tag
   :members:
   :undoc-members:
   :show-inheritance:

nixio.property module
---------------------

.. automodule:: nixio.property
   :members:
   :undoc-members:
   :show-inheritance:

nixio.section module
--------------------

.. automodule:: nixio.section
   :members:
   :undoc-members:
   :show-inheritance:

nixio.source module
-------------------

.. automodule:: nixio.source
   :members:
   :undoc-members:
   :show-inheritance:

nixio.source\_link\_container module
------------------------------------

.. automodule:: nixio.source_link_container
   :members:
   :undoc-members:
   :show-inheritance:

nixio.tag module
----------------

.. automodule:: nixio.tag
   :members:
   :undoc-members:
   :show-inheritance:

nixio.validator module
----------------------

.. automodule:: nixio.validator
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: nixio
   :members:
   :undoc-members:
   :show-inheritance:
